﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Documents.Excel;
using System.IO;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;

namespace ExportToExcelIssue
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
            DataContext = Data.GetData(10000, 200, 400);

            excelExporter.ExportStarted += (ss, ee)
                =>
            {
                border.Visibility = System.Windows.Visibility.Visible;
            };

            excelExporter.ExportEnded += (ss, ee)
                =>
            {
                border.Visibility = System.Windows.Visibility.Collapsed;
                if (stream != null)
                {
                    exportedWorkbook.Save(stream);
                    stream.Close();
                }
            };

            excelExporter.RowExporting += (ss, ee)
             =>
            {
                if (ee.Row is GroupByRow)
                    text.Text = ((ee.Row.Index / (double)ee.Row.Manager.Rows.Count) * 100).ToString("N2");
            };
        }


        Stream stream;
        Workbook exportedWorkbook;
        private void button1_Click(object sender, RoutedEventArgs e)
        {

            SaveFileDialog saveDialog = new SaveFileDialog();
            saveDialog.DefaultExt = "xlsx";
            saveDialog.Filter = "Excel Workbook (.xlsx)|*.xlsx";

            if (saveDialog.ShowDialog().Value)
            {
                try
                {
                    stream = saveDialog.OpenFile();

                    exportedWorkbook = this.ExportWorkbook();
                    exportedWorkbook.Save(stream);
                }
                catch (Exception exc)
                {
                    MessageBox.Show(exc.Message);
                }
            }
        }
        XamGridExcelExporter excelExporter = new XamGridExcelExporter();
        private Workbook ExportWorkbook()
        {
          
            

            // Create a Workbook object and add a sheet in it.
            Workbook workbook = new Workbook();
            Worksheet worksheet = workbook.Worksheets.Add("Sheet1");
            workbook.SetCurrentFormat(WorkbookFormat.Excel2007);

            // Export xamGrid data to the created Workbook object
            this.excelExporter.ExportAsync(this.xamGrid1, workbook);

            return workbook;
        }

    }

    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private int value;
        private string label;
        private DateTime date;


        public DateTime Date
        {
            get { return date; }
            set
            {
                date = value;
                PropChanged("Date");
            }
        }


        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public double Avarage
        {
            get
            {
                return (Open + Close + High + Low) / 4;
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Date = DateTime.Now.AddDays(i),
                    Label = "Item " + i,
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(rangeStart, rangeEnd),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                    Value = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }

}
